@@ -24,6 +24,6 @@
 #ifndef _ALSA_SNDFILE_H
 #define _ALSA_SNDFILE_H
 
-void alsa_play_file(const char *filename, int *stopper);
+void alsa_play_file(const char *filename, const char *device, int *stopper);
 
 #endif  //_ALSA_SNDFILE_H
