@@ -1676,8 +1676,11 @@ eXosip_process_notify_within_dialog(eXosip_subscribe_t *js,
     strncpy(je->sip_event,event_hdr->hvalue,sizeof(je->sip_event));
     if (je->msg_body)
       osip_free(je->msg_body);
-    
-    je->msg_body = osip_strdup(body->body);
+
+    if (body)
+      je->msg_body = osip_strdup(body->body);
+    else
+      je->msg_body = osip_strdup("");
     
     if (je->msg_body == NULL) {
       eXosip_event_free(je);
