@@ -1003,10 +1003,12 @@ static void pyowpl_callback_onNotify(OWPL_NOTIFICATION_INFO * info) {
     PyObject * nInfo;
     OWPL_NOTIFICATION_STATUS_INFO *stInfos;
 
+
     if (info->event == NOTIFICATION_PRESENCE) {
         stInfos = (OWPL_NOTIFICATION_STATUS_INFO *) info->Data.StatusInfo;
-
-        nInfo = Py_BuildValue("(sss)",
+        //FIXME: parsing the content make Python crash
+        //printf("content:%s\n", info->szXmlContent);
+        nInfo = Py_BuildValue("(ds)",
                               info->event,
                               stInfos->szRemoteIdentity,
                               info->szXmlContent);
